@@ -6,20 +6,20 @@ from pathlib import Path
 
 from watchdog.utils.dirsnapshot import DirectorySnapshot
 
-from codex.logger_base import LoggerBaseMixin
-from codex.models import Comic, FailedImport, Folder
+from codex.models import Comic, CustomCover, FailedImport, Folder
 
 
-class CodexDatabaseSnapshot(DirectorySnapshot, LoggerBaseMixin):
+class CodexDatabaseSnapshot(DirectorySnapshot):
     """Take snapshots from the Codex database."""
 
-    MODELS = (Folder, Comic, FailedImport)
+    MODELS = (Folder, Comic, FailedImport, CustomCover)
+    COVERS_ONLY_MODELS = (CustomCover,)
     _STAT_LEN = 10
 
-    @classmethod
-    def _walk(cls, root):
+    def _walk(self, root):
         """Populate the DirectorySnapshot structures from the database."""
-        for model in cls.MODELS:
+        models = self.COVERS_ONLY_MODELS if self._covers_only else self.MODELS
+        for model in models:
             yield (
                 model.objects.filter(library__path=root)
                 .order_by("path")
@@ -57,17 +57,26 @@ class CodexDatabaseSnapshot(DirectorySnapshot, LoggerBaseMixin):
         i = (st.st_ino, st.st_dev)
         self._inode_to_path[i] = path
 
-    def __init__(
+    def __init__(  # noqa: PLR0913 # pyright: ignore[reportMissingSuperCall]
         self,
         path,
-        _recursive=True,  # unused, always recursive
+        *,
+        recursive=True,  # noqa: ARG002
         stat=os.stat,
-        _listdir=os.listdir,  # unused for database
+        listdir=os.scandir,  # noqa: ARG002 unused for database
+        logger_=None,
         force=False,
-        log_queue=None,
+        covers_only=False,
     ):
         """Initialize like DirectorySnapshot but use a database walk."""
-        self.init_logger(log_queue)
+        # Do not call super().__init__(), because it walks.
+        if not logger_:
+            reason = "logger_ must be set"
+            raise ValueError(reason)
+
+        self.log = logger_
+        self.stat = stat
+        self._covers_only = covers_only
         self._stat_info = {}
         self._inode_to_path = {}
         if not Path(path).is_dir():
@@ -75,7 +84,7 @@ class CodexDatabaseSnapshot(DirectorySnapshot, LoggerBaseMixin):
             return
 
         # Add the library root
-        root_stat = stat(path)
+        root_stat = self.stat(path)
         self._set_lookups(path, root_stat)
 
         for wp in chain.from_iterable(self._walk(path)):
