@@ -9,20 +9,17 @@ from django.db.models import (
     CASCADE,
     BooleanField,
     CharField,
-    Choices,
     DateTimeField,
     OneToOneField,
     PositiveSmallIntegerField,
     TextChoices,
 )
 from django.utils.translation import gettext_lazy as _
+from typing_extensions import override
 
-from codex.librarian.covers.status import CoverStatusTypes
-from codex.librarian.importer.status import ImportStatusTypes
-from codex.librarian.janitor.status import JanitorStatusTypes
-from codex.librarian.search.status import SearchIndexStatusTypes
-from codex.librarian.watchdog.status import WatchdogStatusTypes
-from codex.models.base import MAX_FIELD_LEN, MAX_NAME_LEN, BaseModel
+from codex.choices.admin import AdminFlagChoices
+from codex.choices.statii import ADMIN_STATUS_TITLES
+from codex.models.base import MAX_FIELD_LEN, MAX_NAME_LEN, BaseModel, max_choices_len
 
 __all__ = ("AdminFlag", "LibrarianStatus", "Timestamp", "UserActive")
 
@@ -30,20 +27,15 @@ __all__ = ("AdminFlag", "LibrarianStatus", "Timestamp", "UserActive")
 class AdminFlag(BaseModel):
     """Flags set by administrators."""
 
-    class FlagChoices(Choices):
-        """Choices for Admin Flags."""
+    FALSE_DEFAULTS = frozenset({AdminFlagChoices.AUTO_UPDATE})
 
-        FOLDER_VIEW = "FV"
-        REGISTRATION = "RG"
-        NON_USERS = "NU"
-        AUTO_UPDATE = "AU"
-        SEARCH_INDEX_OPTIMIZE = "SO"
-        IMPORT_METADATA = "IM"
-
-    FALSE_DEFAULTS = frozenset({FlagChoices.AUTO_UPDATE})
-
-    key = CharField(db_index=True, max_length=2, choices=FlagChoices.choices)
+    key = CharField(
+        db_index=True,
+        max_length=max_choices_len(AdminFlagChoices),
+        choices=AdminFlagChoices.choices,
+    )
     on = BooleanField(default=True)
+    value = CharField(max_length=MAX_NAME_LEN, default="", blank=True)
 
     class Meta(BaseModel.Meta):
         """Constraints."""
@@ -54,20 +46,18 @@ class AdminFlag(BaseModel):
 class LibrarianStatus(BaseModel):
     """Active Library Tasks."""
 
-    CHOICES = (
-        CoverStatusTypes.choices
-        + ImportStatusTypes.choices
-        + JanitorStatusTypes.choices
-        + SearchIndexStatusTypes.choices
-        + WatchdogStatusTypes.choices
-    )
+    CHOICES = TextChoices("LibrarianStatusTypes", ADMIN_STATUS_TITLES.inverse.items())
 
-    status_type = CharField(db_index=True, max_length=3, choices=CHOICES)
-    preactive = BooleanField(default=False)
+    status_type = CharField(
+        db_index=True,
+        max_length=max_choices_len(CHOICES),
+        choices=CHOICES.choices,  # ty: ignore[unresolved-attribute]
+    )
+    subtitle = CharField(db_index=True, max_length=MAX_NAME_LEN)
     complete = PositiveSmallIntegerField(null=True, default=None)
     total = PositiveSmallIntegerField(null=True, default=None)
+    preactive = DateTimeField(null=True, default=None)
     active = DateTimeField(null=True, default=None)
-    subtitle = CharField(db_index=True, max_length=MAX_NAME_LEN)
 
     class Meta(BaseModel.Meta):
         """Constraints."""
@@ -79,16 +69,19 @@ class LibrarianStatus(BaseModel):
 class Timestamp(BaseModel):
     """Timestamped Named Strings."""
 
-    class TimestampChoices(TextChoices):
+    class Choices(TextChoices):
         """Choices for Timestamps."""
 
-        COVERS = "CV", _("Covers")
-        JANITOR = "JA", _("Janitor")
-        CODEX_VERSION = "VR", _("Codex Version")
-        SEARCH_INDEX_UUID = "SI", _("Search Index UUID")
         API_KEY = "AP", _("API Key")
+        CODEX_VERSION = "VR", _("Codex Version")
+        JANITOR = "JA", _("Janitor")
+        TELEMETER_SENT = "TS", _("Telemeter Sent")
 
-    key = CharField(db_index=True, max_length=2, choices=TimestampChoices.choices)
+    key = CharField(
+        db_index=True,
+        max_length=max_choices_len(Choices),
+        choices=Choices.choices,
+    )
     version = CharField(max_length=MAX_FIELD_LEN, default="")
 
     @classmethod
@@ -108,9 +101,10 @@ class Timestamp(BaseModel):
 
         unique_together = ("key",)
 
-    def __str__(self):
+    @override
+    def __repr__(self):
         """Print name for choice."""
-        return self.TimestampChoices(self.key).name
+        return self.Choices(self.key).name
 
 
 class UserActive(BaseModel):
@@ -124,8 +118,3 @@ class GroupAuth(BaseModel):
 
     group = OneToOneField(Group, db_index=True, on_delete=CASCADE)
     exclude = BooleanField(db_index=True, default=False)
-
-    class Meta(BaseModel.Meta):
-        """Constraints."""
-
-        unique_together = ("group",)
