@@ -1,10 +1,11 @@
 """OPDS v2.0 top links section methods."""
 
 from codex.views.opds.const import MimeType, Rel
-from codex.views.opds.v2.links import HrefData, LinkData, LinksMixin
+from codex.views.opds.v2.href import HrefData
+from codex.views.opds.v2.links import LinkData, OPDS2LinksView
 
 
-class TopLinksMixin(LinksMixin):
+class OPDS2TopLinksView(OPDS2LinksView):
     """OPDS 2.0 top links section methods."""
 
     def _link_auth(self):
@@ -21,15 +22,12 @@ class TopLinksMixin(LinksMixin):
         return self.link(link_data)
 
     def _link_search(self):
-        kwargs = {"group": "s", "pk": 0, "page": 1}
+        kwargs = {"group": "s", "pks": (0,), "page": 1}
         href_data = HrefData(kwargs, absolute_query_params=True, max_page=1)
         link_data = LinkData(Rel.SEARCH, href_data, template="{?query}")
         return self.link(link_data)
 
-    def __init__(self, *args, **kwargs):
-        """Initialize static links."""
-        super().__init__(*args, **kwargs)
-
+    def _get_static_links(self):
         start_href_data = HrefData(
             {}, url_name="opds:v2:start", absolute_query_params=True
         )
@@ -46,7 +44,7 @@ class TopLinksMixin(LinksMixin):
             mime_type=MimeType.HTML,
         )
 
-        self._static_links = (
+        return (
             self._link_auth(),
             self._link_search(),
             self.link(start_link_data),
@@ -55,7 +53,7 @@ class TopLinksMixin(LinksMixin):
 
     def _top_route(self):
         group = "f" if self.kwargs.get("group") == "f" else "r"
-        return {"group": group, "pk": 0, "page": 1}
+        return {"group": group, "pks": (0,), "page": 1}
 
     def _link_page(self, rel, page):
         """Links to a page of results."""
@@ -66,16 +64,21 @@ class TopLinksMixin(LinksMixin):
 
     def get_links(self, up_route):
         """Get the top links section of the feed."""
-        page = self.kwargs.get("page")
+        page = self.kwargs.get("page", 0)
         top_href_data = HrefData(self._top_route())
         top_link_data = LinkData(Rel.TOP, top_href_data)
         up_href_data = HrefData(up_route)
         up_link_data = LinkData(Rel.UP, up_href_data)
         links_data = [
             self.link_self(),
-            *self._static_links,
+            *self._get_static_links(),
             self._link_page("first", 1),
-            self._link_page("previous", page - 1),
+        ]
+        if page > 1:
+            links_data += [
+                self._link_page("previous", page - 1),
+            ]
+        links_data += [
             self._link_page("next", page + 1),
             self._link_page("last", self.num_pages),
             self.link(top_link_data),
