@@ -1,22 +1,23 @@
 """PWA views."""
-from django.views.generic import TemplateView
+
+from codex.views.template import CodexTemplateView
 
 
-class WebManifestView(TemplateView):
+class WebManifestView(CodexTemplateView):
     """Serve the webmanifest spec."""
 
     template_name = "pwa/manifest.webmanifest"
     content_type = "application/manifest+json"
 
 
-class ServiceWorkerRegisterView(TemplateView):
+class ServiceWorkerRegisterView(CodexTemplateView):
     """Serve the serviceworker register javascript."""
 
-    template_name = "pwa/serviceworkerRegister.js"
+    template_name = "pwa/serviceworker-register.js"
     content_type = "application/javascript"
 
 
-class ServiceWorkerView(TemplateView):
+class ServiceWorkerView(CodexTemplateView):
     """Serve the serviceworker javascript."""
 
     template_name = "pwa/serviceworker.js"
